# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: p2p.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\tp2p.proto\x12\tprotowire\"g\n\x17RequestAddressesMessage\x12\x1d\n\x15includeAllSubnetworks\x18\x01 \x01(\x08\x12-\n\x0csubnetworkId\x18\x02 \x01(\x0b\x32\x17.protowire.SubnetworkId\">\n\x10\x41\x64\x64ressesMessage\x12*\n\x0b\x61\x64\x64ressList\x18\x01 \x03(\x0b\x32\x15.protowire.NetAddress\"9\n\nNetAddress\x12\x11\n\ttimestamp\x18\x01 \x01(\x03\x12\n\n\x02ip\x18\x03 \x01(\x0c\x12\x0c\n\x04port\x18\x04 \x01(\r\"\x1d\n\x0cSubnetworkId\x12\r\n\x05\x62ytes\x18\x01 \x01(\x0c\"\xe0\x01\n\x12TransactionMessage\x12\x0f\n\x07version\x18\x01 \x01(\r\x12+\n\x06inputs\x18\x02 \x03(\x0b\x32\x1b.protowire.TransactionInput\x12-\n\x07outputs\x18\x03 \x03(\x0b\x32\x1c.protowire.TransactionOutput\x12\x10\n\x08lockTime\x18\x04 \x01(\x04\x12-\n\x0csubnetworkId\x18\x05 \x01(\x0b\x32\x17.protowire.SubnetworkId\x12\x0b\n\x03gas\x18\x06 \x01(\x04\x12\x0f\n\x07payload\x18\x08 \x01(\x0c\"\x80\x01\n\x10TransactionInput\x12-\n\x10previousOutpoint\x18\x01 \x01(\x0b\x32\x13.protowire.Outpoint\x12\x17\n\x0fsignatureScript\x18\x02 \x01(\x0c\x12\x10\n\x08sequence\x18\x03 \x01(\x04\x12\x12\n\nsigOpCount\x18\x04 \x01(\r\"J\n\x08Outpoint\x12/\n\rtransactionId\x18\x01 \x01(\x0b\x32\x18.protowire.TransactionId\x12\r\n\x05index\x18\x02 \x01(\r\"\x1e\n\rTransactionId\x12\r\n\x05\x62ytes\x18\x01 \x01(\x0c\"2\n\x0fScriptPublicKey\x12\x0e\n\x06script\x18\x01 \x01(\x0c\x12\x0f\n\x07version\x18\x02 \x01(\r\"W\n\x11TransactionOutput\x12\r\n\x05value\x18\x01 \x01(\x04\x12\x33\n\x0fscriptPublicKey\x18\x02 \x01(\x0b\x32\x1a.protowire.ScriptPublicKey\"k\n\x0c\x42lockMessage\x12&\n\x06header\x18\x01 \x01(\x0b\x32\x16.protowire.BlockHeader\x12\x33\n\x0ctransactions\x18\x02 \x03(\x0b\x32\x1d.protowire.TransactionMessage\"\xdc\x02\n\x0b\x42lockHeader\x12\x0f\n\x07version\x18\x01 \x01(\r\x12-\n\x07parents\x18\x0c \x03(\x0b\x32\x1c.protowire.BlockLevelParents\x12\'\n\x0ehashMerkleRoot\x18\x03 \x01(\x0b\x32\x0f.protowire.Hash\x12-\n\x14\x61\x63\x63\x65ptedIdMerkleRoot\x18\x04 \x01(\x0b\x32\x0f.protowire.Hash\x12\'\n\x0eutxoCommitment\x18\x05 \x01(\x0b\x32\x0f.protowire.Hash\x12\x11\n\ttimestamp\x18\x06 \x01(\x03\x12\x0c\n\x04\x62its\x18\x07 \x01(\r\x12\r\n\x05nonce\x18\x08 \x01(\x04\x12\x10\n\x08\x64\x61\x61Score\x18\t \x01(\x04\x12\x10\n\x08\x62lueWork\x18\n \x01(\x0c\x12%\n\x0cpruningPoint\x18\x0e \x01(\x0b\x32\x0f.protowire.Hash\x12\x11\n\tblueScore\x18\r \x01(\x04\":\n\x11\x42lockLevelParents\x12%\n\x0cparentHashes\x18\x01 \x03(\x0b\x32\x0f.protowire.Hash\"\x15\n\x04Hash\x12\r\n\x05\x62ytes\x18\x01 \x01(\x0c\"N\n\x1aRequestBlockLocatorMessage\x12!\n\x08highHash\x18\x01 \x01(\x0b\x32\x0f.protowire.Hash\x12\r\n\x05limit\x18\x02 \x01(\r\"6\n\x13\x42lockLocatorMessage\x12\x1f\n\x06hashes\x18\x01 \x03(\x0b\x32\x0f.protowire.Hash\"\\\n\x15RequestHeadersMessage\x12 \n\x07lowHash\x18\x01 \x01(\x0b\x32\x0f.protowire.Hash\x12!\n\x08highHash\x18\x02 \x01(\x0b\x32\x0f.protowire.Hash\"\x1b\n\x19RequestNextHeadersMessage\"\x14\n\x12\x44oneHeadersMessage\"<\n\x19RequestRelayBlocksMessage\x12\x1f\n\x06hashes\x18\x01 \x03(\x0b\x32\x0f.protowire.Hash\"C\n\x1aRequestTransactionsMessage\x12%\n\x03ids\x18\x01 \x03(\x0b\x32\x18.protowire.TransactionId\"B\n\x1aTransactionNotFoundMessage\x12$\n\x02id\x18\x01 \x01(\x0b\x32\x18.protowire.TransactionId\"5\n\x14InvRelayBlockMessage\x12\x1d\n\x04hash\x18\x01 \x01(\x0b\x32\x0f.protowire.Hash\"?\n\x16InvTransactionsMessage\x12%\n\x03ids\x18\x01 \x03(\x0b\x32\x18.protowire.TransactionId\"\x1c\n\x0bPingMessage\x12\r\n\x05nonce\x18\x01 \x01(\x04\"\x1c\n\x0bPongMessage\x12\r\n\x05nonce\x18\x01 \x01(\x04\"\x0f\n\rVerackMessage\"\xed\x01\n\x0eVersionMessage\x12\x17\n\x0fprotocolVersion\x18\x01 \x01(\r\x12\x10\n\x08services\x18\x02 \x01(\x04\x12\x11\n\ttimestamp\x18\x03 \x01(\x03\x12&\n\x07\x61\x64\x64ress\x18\x04 \x01(\x0b\x32\x15.protowire.NetAddress\x12\n\n\x02id\x18\x05 \x01(\x0c\x12\x11\n\tuserAgent\x18\x06 \x01(\t\x12\x16\n\x0e\x64isableRelayTx\x18\x08 \x01(\x08\x12-\n\x0csubnetworkId\x18\t \x01(\x0b\x32\x17.protowire.SubnetworkId\x12\x0f\n\x07network\x18\n \x01(\t\"\x1f\n\rRejectMessage\x12\x0e\n\x06reason\x18\x01 \x01(\t\"N\n!RequestPruningPointUTXOSetMessage\x12)\n\x10pruningPointHash\x18\x01 \x01(\x0b\x32\x0f.protowire.Hash\"i\n\x1fPruningPointUtxoSetChunkMessage\x12\x46\n\x19outpointAndUtxoEntryPairs\x18\x01 \x03(\x0b\x32#.protowire.OutpointAndUtxoEntryPair\"j\n\x18OutpointAndUtxoEntryPair\x12%\n\x08outpoint\x18\x01 \x01(\x0b\x32\x13.protowire.Outpoint\x12\'\n\tutxoEntry\x18\x02 \x01(\x0b\x32\x14.protowire.UtxoEntry\"{\n\tUtxoEntry\x12\x0e\n\x06\x61mount\x18\x01 \x01(\x04\x12\x33\n\x0fscriptPublicKey\x18\x02 \x01(\x0b\x32\x1a.protowire.ScriptPublicKey\x12\x15\n\rblockDaaScore\x18\x03 \x01(\x04\x12\x12\n\nisCoinbase\x18\x04 \x01(\x08\",\n*RequestNextPruningPointUtxoSetChunkMessage\"&\n$DonePruningPointUtxoSetChunksMessage\":\n\x17RequestIBDBlocksMessage\x12\x1f\n\x06hashes\x18\x01 \x03(\x0b\x32\x0f.protowire.Hash\"\x1f\n\x1dUnexpectedPruningPointMessage\"j\n\x16IbdBlockLocatorMessage\x12#\n\ntargetHash\x18\x01 \x01(\x0b\x32\x0f.protowire.Hash\x12+\n\x12\x62lockLocatorHashes\x18\x02 \x03(\x0b\x32\x0f.protowire.Hash\"i\n\"RequestIBDChainBlockLocatorMessage\x12 \n\x07lowHash\x18\x01 \x01(\x0b\x32\x0f.protowire.Hash\x12!\n\x08highHash\x18\x02 \x01(\x0b\x32\x0f.protowire.Hash\"J\n\x1bIbdChainBlockLocatorMessage\x12+\n\x12\x62lockLocatorHashes\x18\x01 \x03(\x0b\x32\x0f.protowire.Hash\"b\n\x16RequestAnticoneMessage\x12\"\n\tblockHash\x18\x01 \x01(\x0b\x32\x0f.protowire.Hash\x12$\n\x0b\x63ontextHash\x18\x02 \x01(\x0b\x32\x0f.protowire.Hash\"I\n!IbdBlockLocatorHighestHashMessage\x12$\n\x0bhighestHash\x18\x01 \x01(\x0b\x32\x0f.protowire.Hash\"+\n)IbdBlockLocatorHighestHashNotFoundMessage\"C\n\x13\x42lockHeadersMessage\x12,\n\x0c\x62lockHeaders\x18\x01 \x03(\x0b\x32\x16.protowire.BlockHeader\"*\n(RequestPruningPointAndItsAnticoneMessage\"4\n2RequestNextPruningPointAndItsAnticoneBlocksMessage\"\xbb\x01\n\x1b\x42lockWithTrustedDataMessage\x12&\n\x05\x62lock\x18\x01 \x01(\x0b\x32\x17.protowire.BlockMessage\x12\x10\n\x08\x64\x61\x61Score\x18\x02 \x01(\x04\x12&\n\tdaaWindow\x18\x03 \x03(\x0b\x32\x13.protowire.DaaBlock\x12:\n\x0cghostdagData\x18\x04 \x03(\x0b\x32$.protowire.BlockGhostdagDataHashPair\"a\n\x08\x44\x61\x61\x42lock\x12&\n\x05\x62lock\x18\x03 \x01(\x0b\x32\x17.protowire.BlockMessage\x12-\n\x0cghostdagData\x18\x02 \x01(\x0b\x32\x17.protowire.GhostdagData\"c\n\nDaaBlockV4\x12&\n\x06header\x18\x01 \x01(\x0b\x32\x16.protowire.BlockHeader\x12-\n\x0cghostdagData\x18\x02 \x01(\x0b\x32\x17.protowire.GhostdagData\"i\n\x19\x42lockGhostdagDataHashPair\x12\x1d\n\x04hash\x18\x01 \x01(\x0b\x32\x0f.protowire.Hash\x12-\n\x0cghostdagData\x18\x02 \x01(\x0b\x32\x17.protowire.GhostdagData\"\xe6\x01\n\x0cGhostdagData\x12\x11\n\tblueScore\x18\x01 \x01(\x04\x12\x10\n\x08\x62lueWork\x18\x02 \x01(\x0c\x12\'\n\x0eselectedParent\x18\x03 \x01(\x0b\x32\x0f.protowire.Hash\x12&\n\rmergeSetBlues\x18\x04 \x03(\x0b\x32\x0f.protowire.Hash\x12%\n\x0cmergeSetReds\x18\x05 \x03(\x0b\x32\x0f.protowire.Hash\x12\x39\n\x12\x62luesAnticoneSizes\x18\x06 \x03(\x0b\x32\x1d.protowire.BluesAnticoneSizes\"M\n\x12\x42luesAnticoneSizes\x12!\n\x08\x62lueHash\x18\x01 \x01(\x0b\x32\x0f.protowire.Hash\x12\x14\n\x0c\x61nticoneSize\x18\x02 \x01(\r\"\"\n DoneBlocksWithTrustedDataMessage\"?\n\x14PruningPointsMessage\x12\'\n\x07headers\x18\x01 \x03(\x0b\x32\x16.protowire.BlockHeader\"!\n\x1fRequestPruningPointProofMessage\"T\n\x18PruningPointProofMessage\x12\x38\n\x07headers\x18\x01 \x03(\x0b\x32\'.protowire.PruningPointProofHeaderArray\"G\n\x1cPruningPointProofHeaderArray\x12\'\n\x07headers\x18\x01 \x03(\x0b\x32\x16.protowire.BlockHeader\"\x0e\n\x0cReadyMessage\"~\n\x1d\x42lockWithTrustedDataV4Message\x12&\n\x05\x62lock\x18\x01 \x01(\x0b\x32\x17.protowire.BlockMessage\x12\x18\n\x10\x64\x61\x61WindowIndices\x18\x02 \x03(\x04\x12\x1b\n\x13ghostdagDataIndices\x18\x03 \x03(\x04\"z\n\x12TrustedDataMessage\x12(\n\tdaaWindow\x18\x01 \x03(\x0b\x32\x15.protowire.DaaBlockV4\x12:\n\x0cghostdagData\x18\x02 \x03(\x0b\x32$.protowire.BlockGhostdagDataHashPairB&Z$github.com/kaspanet/kaspad/protowireb\x06proto3')



_REQUESTADDRESSESMESSAGE = DESCRIPTOR.message_types_by_name['RequestAddressesMessage']
_ADDRESSESMESSAGE = DESCRIPTOR.message_types_by_name['AddressesMessage']
_NETADDRESS = DESCRIPTOR.message_types_by_name['NetAddress']
_SUBNETWORKID = DESCRIPTOR.message_types_by_name['SubnetworkId']
_TRANSACTIONMESSAGE = DESCRIPTOR.message_types_by_name['TransactionMessage']
_TRANSACTIONINPUT = DESCRIPTOR.message_types_by_name['TransactionInput']
_OUTPOINT = DESCRIPTOR.message_types_by_name['Outpoint']
_TRANSACTIONID = DESCRIPTOR.message_types_by_name['TransactionId']
_SCRIPTPUBLICKEY = DESCRIPTOR.message_types_by_name['ScriptPublicKey']
_TRANSACTIONOUTPUT = DESCRIPTOR.message_types_by_name['TransactionOutput']
_BLOCKMESSAGE = DESCRIPTOR.message_types_by_name['BlockMessage']
_BLOCKHEADER = DESCRIPTOR.message_types_by_name['BlockHeader']
_BLOCKLEVELPARENTS = DESCRIPTOR.message_types_by_name['BlockLevelParents']
_HASH = DESCRIPTOR.message_types_by_name['Hash']
_REQUESTBLOCKLOCATORMESSAGE = DESCRIPTOR.message_types_by_name['RequestBlockLocatorMessage']
_BLOCKLOCATORMESSAGE = DESCRIPTOR.message_types_by_name['BlockLocatorMessage']
_REQUESTHEADERSMESSAGE = DESCRIPTOR.message_types_by_name['RequestHeadersMessage']
_REQUESTNEXTHEADERSMESSAGE = DESCRIPTOR.message_types_by_name['RequestNextHeadersMessage']
_DONEHEADERSMESSAGE = DESCRIPTOR.message_types_by_name['DoneHeadersMessage']
_REQUESTRELAYBLOCKSMESSAGE = DESCRIPTOR.message_types_by_name['RequestRelayBlocksMessage']
_REQUESTTRANSACTIONSMESSAGE = DESCRIPTOR.message_types_by_name['RequestTransactionsMessage']
_TRANSACTIONNOTFOUNDMESSAGE = DESCRIPTOR.message_types_by_name['TransactionNotFoundMessage']
_INVRELAYBLOCKMESSAGE = DESCRIPTOR.message_types_by_name['InvRelayBlockMessage']
_INVTRANSACTIONSMESSAGE = DESCRIPTOR.message_types_by_name['InvTransactionsMessage']
_PINGMESSAGE = DESCRIPTOR.message_types_by_name['PingMessage']
_PONGMESSAGE = DESCRIPTOR.message_types_by_name['PongMessage']
_VERACKMESSAGE = DESCRIPTOR.message_types_by_name['VerackMessage']
_VERSIONMESSAGE = DESCRIPTOR.message_types_by_name['VersionMessage']
_REJECTMESSAGE = DESCRIPTOR.message_types_by_name['RejectMessage']
_REQUESTPRUNINGPOINTUTXOSETMESSAGE = DESCRIPTOR.message_types_by_name['RequestPruningPointUTXOSetMessage']
_PRUNINGPOINTUTXOSETCHUNKMESSAGE = DESCRIPTOR.message_types_by_name['PruningPointUtxoSetChunkMessage']
_OUTPOINTANDUTXOENTRYPAIR = DESCRIPTOR.message_types_by_name['OutpointAndUtxoEntryPair']
_UTXOENTRY = DESCRIPTOR.message_types_by_name['UtxoEntry']
_REQUESTNEXTPRUNINGPOINTUTXOSETCHUNKMESSAGE = DESCRIPTOR.message_types_by_name['RequestNextPruningPointUtxoSetChunkMessage']
_DONEPRUNINGPOINTUTXOSETCHUNKSMESSAGE = DESCRIPTOR.message_types_by_name['DonePruningPointUtxoSetChunksMessage']
_REQUESTIBDBLOCKSMESSAGE = DESCRIPTOR.message_types_by_name['RequestIBDBlocksMessage']
_UNEXPECTEDPRUNINGPOINTMESSAGE = DESCRIPTOR.message_types_by_name['UnexpectedPruningPointMessage']
_IBDBLOCKLOCATORMESSAGE = DESCRIPTOR.message_types_by_name['IbdBlockLocatorMessage']
_REQUESTIBDCHAINBLOCKLOCATORMESSAGE = DESCRIPTOR.message_types_by_name['RequestIBDChainBlockLocatorMessage']
_IBDCHAINBLOCKLOCATORMESSAGE = DESCRIPTOR.message_types_by_name['IbdChainBlockLocatorMessage']
_REQUESTANTICONEMESSAGE = DESCRIPTOR.message_types_by_name['RequestAnticoneMessage']
_IBDBLOCKLOCATORHIGHESTHASHMESSAGE = DESCRIPTOR.message_types_by_name['IbdBlockLocatorHighestHashMessage']
_IBDBLOCKLOCATORHIGHESTHASHNOTFOUNDMESSAGE = DESCRIPTOR.message_types_by_name['IbdBlockLocatorHighestHashNotFoundMessage']
_BLOCKHEADERSMESSAGE = DESCRIPTOR.message_types_by_name['BlockHeadersMessage']
_REQUESTPRUNINGPOINTANDITSANTICONEMESSAGE = DESCRIPTOR.message_types_by_name['RequestPruningPointAndItsAnticoneMessage']
_REQUESTNEXTPRUNINGPOINTANDITSANTICONEBLOCKSMESSAGE = DESCRIPTOR.message_types_by_name['RequestNextPruningPointAndItsAnticoneBlocksMessage']
_BLOCKWITHTRUSTEDDATAMESSAGE = DESCRIPTOR.message_types_by_name['BlockWithTrustedDataMessage']
_DAABLOCK = DESCRIPTOR.message_types_by_name['DaaBlock']
_DAABLOCKV4 = DESCRIPTOR.message_types_by_name['DaaBlockV4']
_BLOCKGHOSTDAGDATAHASHPAIR = DESCRIPTOR.message_types_by_name['BlockGhostdagDataHashPair']
_GHOSTDAGDATA = DESCRIPTOR.message_types_by_name['GhostdagData']
_BLUESANTICONESIZES = DESCRIPTOR.message_types_by_name['BluesAnticoneSizes']
_DONEBLOCKSWITHTRUSTEDDATAMESSAGE = DESCRIPTOR.message_types_by_name['DoneBlocksWithTrustedDataMessage']
_PRUNINGPOINTSMESSAGE = DESCRIPTOR.message_types_by_name['PruningPointsMessage']
_REQUESTPRUNINGPOINTPROOFMESSAGE = DESCRIPTOR.message_types_by_name['RequestPruningPointProofMessage']
_PRUNINGPOINTPROOFMESSAGE = DESCRIPTOR.message_types_by_name['PruningPointProofMessage']
_PRUNINGPOINTPROOFHEADERARRAY = DESCRIPTOR.message_types_by_name['PruningPointProofHeaderArray']
_READYMESSAGE = DESCRIPTOR.message_types_by_name['ReadyMessage']
_BLOCKWITHTRUSTEDDATAV4MESSAGE = DESCRIPTOR.message_types_by_name['BlockWithTrustedDataV4Message']
_TRUSTEDDATAMESSAGE = DESCRIPTOR.message_types_by_name['TrustedDataMessage']
RequestAddressesMessage = _reflection.GeneratedProtocolMessageType('RequestAddressesMessage', (_message.Message,), {
  'DESCRIPTOR' : _REQUESTADDRESSESMESSAGE,
  '__module__' : 'p2p_pb2'
  # @@protoc_insertion_point(class_scope:protowire.RequestAddressesMessage)
  })
_sym_db.RegisterMessage(RequestAddressesMessage)

AddressesMessage = _reflection.GeneratedProtocolMessageType('AddressesMessage', (_message.Message,), {
  'DESCRIPTOR' : _ADDRESSESMESSAGE,
  '__module__' : 'p2p_pb2'
  # @@protoc_insertion_point(class_scope:protowire.AddressesMessage)
  })
_sym_db.RegisterMessage(AddressesMessage)

NetAddress = _reflection.GeneratedProtocolMessageType('NetAddress', (_message.Message,), {
  'DESCRIPTOR' : _NETADDRESS,
  '__module__' : 'p2p_pb2'
  # @@protoc_insertion_point(class_scope:protowire.NetAddress)
  })
_sym_db.RegisterMessage(NetAddress)

SubnetworkId = _reflection.GeneratedProtocolMessageType('SubnetworkId', (_message.Message,), {
  'DESCRIPTOR' : _SUBNETWORKID,
  '__module__' : 'p2p_pb2'
  # @@protoc_insertion_point(class_scope:protowire.SubnetworkId)
  })
_sym_db.RegisterMessage(SubnetworkId)

TransactionMessage = _reflection.GeneratedProtocolMessageType('TransactionMessage', (_message.Message,), {
  'DESCRIPTOR' : _TRANSACTIONMESSAGE,
  '__module__' : 'p2p_pb2'
  # @@protoc_insertion_point(class_scope:protowire.TransactionMessage)
  })
_sym_db.RegisterMessage(TransactionMessage)

TransactionInput = _reflection.GeneratedProtocolMessageType('TransactionInput', (_message.Message,), {
  'DESCRIPTOR' : _TRANSACTIONINPUT,
  '__module__' : 'p2p_pb2'
  # @@protoc_insertion_point(class_scope:protowire.TransactionInput)
  })
_sym_db.RegisterMessage(TransactionInput)

Outpoint = _reflection.GeneratedProtocolMessageType('Outpoint', (_message.Message,), {
  'DESCRIPTOR' : _OUTPOINT,
  '__module__' : 'p2p_pb2'
  # @@protoc_insertion_point(class_scope:protowire.Outpoint)
  })
_sym_db.RegisterMessage(Outpoint)

TransactionId = _reflection.GeneratedProtocolMessageType('TransactionId', (_message.Message,), {
  'DESCRIPTOR' : _TRANSACTIONID,
  '__module__' : 'p2p_pb2'
  # @@protoc_insertion_point(class_scope:protowire.TransactionId)
  })
_sym_db.RegisterMessage(TransactionId)

ScriptPublicKey = _reflection.GeneratedProtocolMessageType('ScriptPublicKey', (_message.Message,), {
  'DESCRIPTOR' : _SCRIPTPUBLICKEY,
  '__module__' : 'p2p_pb2'
  # @@protoc_insertion_point(class_scope:protowire.ScriptPublicKey)
  })
_sym_db.RegisterMessage(ScriptPublicKey)

TransactionOutput = _reflection.GeneratedProtocolMessageType('TransactionOutput', (_message.Message,), {
  'DESCRIPTOR' : _TRANSACTIONOUTPUT,
  '__module__' : 'p2p_pb2'
  # @@protoc_insertion_point(class_scope:protowire.TransactionOutput)
  })
_sym_db.RegisterMessage(TransactionOutput)

BlockMessage = _reflection.GeneratedProtocolMessageType('BlockMessage', (_message.Message,), {
  'DESCRIPTOR' : _BLOCKMESSAGE,
  '__module__' : 'p2p_pb2'
  # @@protoc_insertion_point(class_scope:protowire.BlockMessage)
  })
_sym_db.RegisterMessage(BlockMessage)

BlockHeader = _reflection.GeneratedProtocolMessageType('BlockHeader', (_message.Message,), {
  'DESCRIPTOR' : _BLOCKHEADER,
  '__module__' : 'p2p_pb2'
  # @@protoc_insertion_point(class_scope:protowire.BlockHeader)
  })
_sym_db.RegisterMessage(BlockHeader)

BlockLevelParents = _reflection.GeneratedProtocolMessageType('BlockLevelParents', (_message.Message,), {
  'DESCRIPTOR' : _BLOCKLEVELPARENTS,
  '__module__' : 'p2p_pb2'
  # @@protoc_insertion_point(class_scope:protowire.BlockLevelParents)
  })
_sym_db.RegisterMessage(BlockLevelParents)

Hash = _reflection.GeneratedProtocolMessageType('Hash', (_message.Message,), {
  'DESCRIPTOR' : _HASH,
  '__module__' : 'p2p_pb2'
  # @@protoc_insertion_point(class_scope:protowire.Hash)
  })
_sym_db.RegisterMessage(Hash)

RequestBlockLocatorMessage = _reflection.GeneratedProtocolMessageType('RequestBlockLocatorMessage', (_message.Message,), {
  'DESCRIPTOR' : _REQUESTBLOCKLOCATORMESSAGE,
  '__module__' : 'p2p_pb2'
  # @@protoc_insertion_point(class_scope:protowire.RequestBlockLocatorMessage)
  })
_sym_db.RegisterMessage(RequestBlockLocatorMessage)

BlockLocatorMessage = _reflection.GeneratedProtocolMessageType('BlockLocatorMessage', (_message.Message,), {
  'DESCRIPTOR' : _BLOCKLOCATORMESSAGE,
  '__module__' : 'p2p_pb2'
  # @@protoc_insertion_point(class_scope:protowire.BlockLocatorMessage)
  })
_sym_db.RegisterMessage(BlockLocatorMessage)

RequestHeadersMessage = _reflection.GeneratedProtocolMessageType('RequestHeadersMessage', (_message.Message,), {
  'DESCRIPTOR' : _REQUESTHEADERSMESSAGE,
  '__module__' : 'p2p_pb2'
  # @@protoc_insertion_point(class_scope:protowire.RequestHeadersMessage)
  })
_sym_db.RegisterMessage(RequestHeadersMessage)

RequestNextHeadersMessage = _reflection.GeneratedProtocolMessageType('RequestNextHeadersMessage', (_message.Message,), {
  'DESCRIPTOR' : _REQUESTNEXTHEADERSMESSAGE,
  '__module__' : 'p2p_pb2'
  # @@protoc_insertion_point(class_scope:protowire.RequestNextHeadersMessage)
  })
_sym_db.RegisterMessage(RequestNextHeadersMessage)

DoneHeadersMessage = _reflection.GeneratedProtocolMessageType('DoneHeadersMessage', (_message.Message,), {
  'DESCRIPTOR' : _DONEHEADERSMESSAGE,
  '__module__' : 'p2p_pb2'
  # @@protoc_insertion_point(class_scope:protowire.DoneHeadersMessage)
  })
_sym_db.RegisterMessage(DoneHeadersMessage)

RequestRelayBlocksMessage = _reflection.GeneratedProtocolMessageType('RequestRelayBlocksMessage', (_message.Message,), {
  'DESCRIPTOR' : _REQUESTRELAYBLOCKSMESSAGE,
  '__module__' : 'p2p_pb2'
  # @@protoc_insertion_point(class_scope:protowire.RequestRelayBlocksMessage)
  })
_sym_db.RegisterMessage(RequestRelayBlocksMessage)

RequestTransactionsMessage = _reflection.GeneratedProtocolMessageType('RequestTransactionsMessage', (_message.Message,), {
  'DESCRIPTOR' : _REQUESTTRANSACTIONSMESSAGE,
  '__module__' : 'p2p_pb2'
  # @@protoc_insertion_point(class_scope:protowire.RequestTransactionsMessage)
  })
_sym_db.RegisterMessage(RequestTransactionsMessage)

TransactionNotFoundMessage = _reflection.GeneratedProtocolMessageType('TransactionNotFoundMessage', (_message.Message,), {
  'DESCRIPTOR' : _TRANSACTIONNOTFOUNDMESSAGE,
  '__module__' : 'p2p_pb2'
  # @@protoc_insertion_point(class_scope:protowire.TransactionNotFoundMessage)
  })
_sym_db.RegisterMessage(TransactionNotFoundMessage)

InvRelayBlockMessage = _reflection.GeneratedProtocolMessageType('InvRelayBlockMessage', (_message.Message,), {
  'DESCRIPTOR' : _INVRELAYBLOCKMESSAGE,
  '__module__' : 'p2p_pb2'
  # @@protoc_insertion_point(class_scope:protowire.InvRelayBlockMessage)
  })
_sym_db.RegisterMessage(InvRelayBlockMessage)

InvTransactionsMessage = _reflection.GeneratedProtocolMessageType('InvTransactionsMessage', (_message.Message,), {
  'DESCRIPTOR' : _INVTRANSACTIONSMESSAGE,
  '__module__' : 'p2p_pb2'
  # @@protoc_insertion_point(class_scope:protowire.InvTransactionsMessage)
  })
_sym_db.RegisterMessage(InvTransactionsMessage)

PingMessage = _reflection.GeneratedProtocolMessageType('PingMessage', (_message.Message,), {
  'DESCRIPTOR' : _PINGMESSAGE,
  '__module__' : 'p2p_pb2'
  # @@protoc_insertion_point(class_scope:protowire.PingMessage)
  })
_sym_db.RegisterMessage(PingMessage)

PongMessage = _reflection.GeneratedProtocolMessageType('PongMessage', (_message.Message,), {
  'DESCRIPTOR' : _PONGMESSAGE,
  '__module__' : 'p2p_pb2'
  # @@protoc_insertion_point(class_scope:protowire.PongMessage)
  })
_sym_db.RegisterMessage(PongMessage)

VerackMessage = _reflection.GeneratedProtocolMessageType('VerackMessage', (_message.Message,), {
  'DESCRIPTOR' : _VERACKMESSAGE,
  '__module__' : 'p2p_pb2'
  # @@protoc_insertion_point(class_scope:protowire.VerackMessage)
  })
_sym_db.RegisterMessage(VerackMessage)

VersionMessage = _reflection.GeneratedProtocolMessageType('VersionMessage', (_message.Message,), {
  'DESCRIPTOR' : _VERSIONMESSAGE,
  '__module__' : 'p2p_pb2'
  # @@protoc_insertion_point(class_scope:protowire.VersionMessage)
  })
_sym_db.RegisterMessage(VersionMessage)

RejectMessage = _reflection.GeneratedProtocolMessageType('RejectMessage', (_message.Message,), {
  'DESCRIPTOR' : _REJECTMESSAGE,
  '__module__' : 'p2p_pb2'
  # @@protoc_insertion_point(class_scope:protowire.RejectMessage)
  })
_sym_db.RegisterMessage(RejectMessage)

RequestPruningPointUTXOSetMessage = _reflection.GeneratedProtocolMessageType('RequestPruningPointUTXOSetMessage', (_message.Message,), {
  'DESCRIPTOR' : _REQUESTPRUNINGPOINTUTXOSETMESSAGE,
  '__module__' : 'p2p_pb2'
  # @@protoc_insertion_point(class_scope:protowire.RequestPruningPointUTXOSetMessage)
  })
_sym_db.RegisterMessage(RequestPruningPointUTXOSetMessage)

PruningPointUtxoSetChunkMessage = _reflection.GeneratedProtocolMessageType('PruningPointUtxoSetChunkMessage', (_message.Message,), {
  'DESCRIPTOR' : _PRUNINGPOINTUTXOSETCHUNKMESSAGE,
  '__module__' : 'p2p_pb2'
  # @@protoc_insertion_point(class_scope:protowire.PruningPointUtxoSetChunkMessage)
  })
_sym_db.RegisterMessage(PruningPointUtxoSetChunkMessage)

OutpointAndUtxoEntryPair = _reflection.GeneratedProtocolMessageType('OutpointAndUtxoEntryPair', (_message.Message,), {
  'DESCRIPTOR' : _OUTPOINTANDUTXOENTRYPAIR,
  '__module__' : 'p2p_pb2'
  # @@protoc_insertion_point(class_scope:protowire.OutpointAndUtxoEntryPair)
  })
_sym_db.RegisterMessage(OutpointAndUtxoEntryPair)

UtxoEntry = _reflection.GeneratedProtocolMessageType('UtxoEntry', (_message.Message,), {
  'DESCRIPTOR' : _UTXOENTRY,
  '__module__' : 'p2p_pb2'
  # @@protoc_insertion_point(class_scope:protowire.UtxoEntry)
  })
_sym_db.RegisterMessage(UtxoEntry)

RequestNextPruningPointUtxoSetChunkMessage = _reflection.GeneratedProtocolMessageType('RequestNextPruningPointUtxoSetChunkMessage', (_message.Message,), {
  'DESCRIPTOR' : _REQUESTNEXTPRUNINGPOINTUTXOSETCHUNKMESSAGE,
  '__module__' : 'p2p_pb2'
  # @@protoc_insertion_point(class_scope:protowire.RequestNextPruningPointUtxoSetChunkMessage)
  })
_sym_db.RegisterMessage(RequestNextPruningPointUtxoSetChunkMessage)

DonePruningPointUtxoSetChunksMessage = _reflection.GeneratedProtocolMessageType('DonePruningPointUtxoSetChunksMessage', (_message.Message,), {
  'DESCRIPTOR' : _DONEPRUNINGPOINTUTXOSETCHUNKSMESSAGE,
  '__module__' : 'p2p_pb2'
  # @@protoc_insertion_point(class_scope:protowire.DonePruningPointUtxoSetChunksMessage)
  })
_sym_db.RegisterMessage(DonePruningPointUtxoSetChunksMessage)

RequestIBDBlocksMessage = _reflection.GeneratedProtocolMessageType('RequestIBDBlocksMessage', (_message.Message,), {
  'DESCRIPTOR' : _REQUESTIBDBLOCKSMESSAGE,
  '__module__' : 'p2p_pb2'
  # @@protoc_insertion_point(class_scope:protowire.RequestIBDBlocksMessage)
  })
_sym_db.RegisterMessage(RequestIBDBlocksMessage)

UnexpectedPruningPointMessage = _reflection.GeneratedProtocolMessageType('UnexpectedPruningPointMessage', (_message.Message,), {
  'DESCRIPTOR' : _UNEXPECTEDPRUNINGPOINTMESSAGE,
  '__module__' : 'p2p_pb2'
  # @@protoc_insertion_point(class_scope:protowire.UnexpectedPruningPointMessage)
  })
_sym_db.RegisterMessage(UnexpectedPruningPointMessage)

IbdBlockLocatorMessage = _reflection.GeneratedProtocolMessageType('IbdBlockLocatorMessage', (_message.Message,), {
  'DESCRIPTOR' : _IBDBLOCKLOCATORMESSAGE,
  '__module__' : 'p2p_pb2'
  # @@protoc_insertion_point(class_scope:protowire.IbdBlockLocatorMessage)
  })
_sym_db.RegisterMessage(IbdBlockLocatorMessage)

RequestIBDChainBlockLocatorMessage = _reflection.GeneratedProtocolMessageType('RequestIBDChainBlockLocatorMessage', (_message.Message,), {
  'DESCRIPTOR' : _REQUESTIBDCHAINBLOCKLOCATORMESSAGE,
  '__module__' : 'p2p_pb2'
  # @@protoc_insertion_point(class_scope:protowire.RequestIBDChainBlockLocatorMessage)
  })
_sym_db.RegisterMessage(RequestIBDChainBlockLocatorMessage)

IbdChainBlockLocatorMessage = _reflection.GeneratedProtocolMessageType('IbdChainBlockLocatorMessage', (_message.Message,), {
  'DESCRIPTOR' : _IBDCHAINBLOCKLOCATORMESSAGE,
  '__module__' : 'p2p_pb2'
  # @@protoc_insertion_point(class_scope:protowire.IbdChainBlockLocatorMessage)
  })
_sym_db.RegisterMessage(IbdChainBlockLocatorMessage)

RequestAnticoneMessage = _reflection.GeneratedProtocolMessageType('RequestAnticoneMessage', (_message.Message,), {
  'DESCRIPTOR' : _REQUESTANTICONEMESSAGE,
  '__module__' : 'p2p_pb2'
  # @@protoc_insertion_point(class_scope:protowire.RequestAnticoneMessage)
  })
_sym_db.RegisterMessage(RequestAnticoneMessage)

IbdBlockLocatorHighestHashMessage = _reflection.GeneratedProtocolMessageType('IbdBlockLocatorHighestHashMessage', (_message.Message,), {
  'DESCRIPTOR' : _IBDBLOCKLOCATORHIGHESTHASHMESSAGE,
  '__module__' : 'p2p_pb2'
  # @@protoc_insertion_point(class_scope:protowire.IbdBlockLocatorHighestHashMessage)
  })
_sym_db.RegisterMessage(IbdBlockLocatorHighestHashMessage)

IbdBlockLocatorHighestHashNotFoundMessage = _reflection.GeneratedProtocolMessageType('IbdBlockLocatorHighestHashNotFoundMessage', (_message.Message,), {
  'DESCRIPTOR' : _IBDBLOCKLOCATORHIGHESTHASHNOTFOUNDMESSAGE,
  '__module__' : 'p2p_pb2'
  # @@protoc_insertion_point(class_scope:protowire.IbdBlockLocatorHighestHashNotFoundMessage)
  })
_sym_db.RegisterMessage(IbdBlockLocatorHighestHashNotFoundMessage)

BlockHeadersMessage = _reflection.GeneratedProtocolMessageType('BlockHeadersMessage', (_message.Message,), {
  'DESCRIPTOR' : _BLOCKHEADERSMESSAGE,
  '__module__' : 'p2p_pb2'
  # @@protoc_insertion_point(class_scope:protowire.BlockHeadersMessage)
  })
_sym_db.RegisterMessage(BlockHeadersMessage)

RequestPruningPointAndItsAnticoneMessage = _reflection.GeneratedProtocolMessageType('RequestPruningPointAndItsAnticoneMessage', (_message.Message,), {
  'DESCRIPTOR' : _REQUESTPRUNINGPOINTANDITSANTICONEMESSAGE,
  '__module__' : 'p2p_pb2'
  # @@protoc_insertion_point(class_scope:protowire.RequestPruningPointAndItsAnticoneMessage)
  })
_sym_db.RegisterMessage(RequestPruningPointAndItsAnticoneMessage)

RequestNextPruningPointAndItsAnticoneBlocksMessage = _reflection.GeneratedProtocolMessageType('RequestNextPruningPointAndItsAnticoneBlocksMessage', (_message.Message,), {
  'DESCRIPTOR' : _REQUESTNEXTPRUNINGPOINTANDITSANTICONEBLOCKSMESSAGE,
  '__module__' : 'p2p_pb2'
  # @@protoc_insertion_point(class_scope:protowire.RequestNextPruningPointAndItsAnticoneBlocksMessage)
  })
_sym_db.RegisterMessage(RequestNextPruningPointAndItsAnticoneBlocksMessage)

BlockWithTrustedDataMessage = _reflection.GeneratedProtocolMessageType('BlockWithTrustedDataMessage', (_message.Message,), {
  'DESCRIPTOR' : _BLOCKWITHTRUSTEDDATAMESSAGE,
  '__module__' : 'p2p_pb2'
  # @@protoc_insertion_point(class_scope:protowire.BlockWithTrustedDataMessage)
  })
_sym_db.RegisterMessage(BlockWithTrustedDataMessage)

DaaBlock = _reflection.GeneratedProtocolMessageType('DaaBlock', (_message.Message,), {
  'DESCRIPTOR' : _DAABLOCK,
  '__module__' : 'p2p_pb2'
  # @@protoc_insertion_point(class_scope:protowire.DaaBlock)
  })
_sym_db.RegisterMessage(DaaBlock)

DaaBlockV4 = _reflection.GeneratedProtocolMessageType('DaaBlockV4', (_message.Message,), {
  'DESCRIPTOR' : _DAABLOCKV4,
  '__module__' : 'p2p_pb2'
  # @@protoc_insertion_point(class_scope:protowire.DaaBlockV4)
  })
_sym_db.RegisterMessage(DaaBlockV4)

BlockGhostdagDataHashPair = _reflection.GeneratedProtocolMessageType('BlockGhostdagDataHashPair', (_message.Message,), {
  'DESCRIPTOR' : _BLOCKGHOSTDAGDATAHASHPAIR,
  '__module__' : 'p2p_pb2'
  # @@protoc_insertion_point(class_scope:protowire.BlockGhostdagDataHashPair)
  })
_sym_db.RegisterMessage(BlockGhostdagDataHashPair)

GhostdagData = _reflection.GeneratedProtocolMessageType('GhostdagData', (_message.Message,), {
  'DESCRIPTOR' : _GHOSTDAGDATA,
  '__module__' : 'p2p_pb2'
  # @@protoc_insertion_point(class_scope:protowire.GhostdagData)
  })
_sym_db.RegisterMessage(GhostdagData)

BluesAnticoneSizes = _reflection.GeneratedProtocolMessageType('BluesAnticoneSizes', (_message.Message,), {
  'DESCRIPTOR' : _BLUESANTICONESIZES,
  '__module__' : 'p2p_pb2'
  # @@protoc_insertion_point(class_scope:protowire.BluesAnticoneSizes)
  })
_sym_db.RegisterMessage(BluesAnticoneSizes)

DoneBlocksWithTrustedDataMessage = _reflection.GeneratedProtocolMessageType('DoneBlocksWithTrustedDataMessage', (_message.Message,), {
  'DESCRIPTOR' : _DONEBLOCKSWITHTRUSTEDDATAMESSAGE,
  '__module__' : 'p2p_pb2'
  # @@protoc_insertion_point(class_scope:protowire.DoneBlocksWithTrustedDataMessage)
  })
_sym_db.RegisterMessage(DoneBlocksWithTrustedDataMessage)

PruningPointsMessage = _reflection.GeneratedProtocolMessageType('PruningPointsMessage', (_message.Message,), {
  'DESCRIPTOR' : _PRUNINGPOINTSMESSAGE,
  '__module__' : 'p2p_pb2'
  # @@protoc_insertion_point(class_scope:protowire.PruningPointsMessage)
  })
_sym_db.RegisterMessage(PruningPointsMessage)

RequestPruningPointProofMessage = _reflection.GeneratedProtocolMessageType('RequestPruningPointProofMessage', (_message.Message,), {
  'DESCRIPTOR' : _REQUESTPRUNINGPOINTPROOFMESSAGE,
  '__module__' : 'p2p_pb2'
  # @@protoc_insertion_point(class_scope:protowire.RequestPruningPointProofMessage)
  })
_sym_db.RegisterMessage(RequestPruningPointProofMessage)

PruningPointProofMessage = _reflection.GeneratedProtocolMessageType('PruningPointProofMessage', (_message.Message,), {
  'DESCRIPTOR' : _PRUNINGPOINTPROOFMESSAGE,
  '__module__' : 'p2p_pb2'
  # @@protoc_insertion_point(class_scope:protowire.PruningPointProofMessage)
  })
_sym_db.RegisterMessage(PruningPointProofMessage)

PruningPointProofHeaderArray = _reflection.GeneratedProtocolMessageType('PruningPointProofHeaderArray', (_message.Message,), {
  'DESCRIPTOR' : _PRUNINGPOINTPROOFHEADERARRAY,
  '__module__' : 'p2p_pb2'
  # @@protoc_insertion_point(class_scope:protowire.PruningPointProofHeaderArray)
  })
_sym_db.RegisterMessage(PruningPointProofHeaderArray)

ReadyMessage = _reflection.GeneratedProtocolMessageType('ReadyMessage', (_message.Message,), {
  'DESCRIPTOR' : _READYMESSAGE,
  '__module__' : 'p2p_pb2'
  # @@protoc_insertion_point(class_scope:protowire.ReadyMessage)
  })
_sym_db.RegisterMessage(ReadyMessage)

BlockWithTrustedDataV4Message = _reflection.GeneratedProtocolMessageType('BlockWithTrustedDataV4Message', (_message.Message,), {
  'DESCRIPTOR' : _BLOCKWITHTRUSTEDDATAV4MESSAGE,
  '__module__' : 'p2p_pb2'
  # @@protoc_insertion_point(class_scope:protowire.BlockWithTrustedDataV4Message)
  })
_sym_db.RegisterMessage(BlockWithTrustedDataV4Message)

TrustedDataMessage = _reflection.GeneratedProtocolMessageType('TrustedDataMessage', (_message.Message,), {
  'DESCRIPTOR' : _TRUSTEDDATAMESSAGE,
  '__module__' : 'p2p_pb2'
  # @@protoc_insertion_point(class_scope:protowire.TrustedDataMessage)
  })
_sym_db.RegisterMessage(TrustedDataMessage)

if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z$github.com/kaspanet/kaspad/protowire'
  _REQUESTADDRESSESMESSAGE._serialized_start=24
  _REQUESTADDRESSESMESSAGE._serialized_end=127
  _ADDRESSESMESSAGE._serialized_start=129
  _ADDRESSESMESSAGE._serialized_end=191
  _NETADDRESS._serialized_start=193
  _NETADDRESS._serialized_end=250
  _SUBNETWORKID._serialized_start=252
  _SUBNETWORKID._serialized_end=281
  _TRANSACTIONMESSAGE._serialized_start=284
  _TRANSACTIONMESSAGE._serialized_end=508
  _TRANSACTIONINPUT._serialized_start=511
  _TRANSACTIONINPUT._serialized_end=639
  _OUTPOINT._serialized_start=641
  _OUTPOINT._serialized_end=715
  _TRANSACTIONID._serialized_start=717
  _TRANSACTIONID._serialized_end=747
  _SCRIPTPUBLICKEY._serialized_start=749
  _SCRIPTPUBLICKEY._serialized_end=799
  _TRANSACTIONOUTPUT._serialized_start=801
  _TRANSACTIONOUTPUT._serialized_end=888
  _BLOCKMESSAGE._serialized_start=890
  _BLOCKMESSAGE._serialized_end=997
  _BLOCKHEADER._serialized_start=1000
  _BLOCKHEADER._serialized_end=1348
  _BLOCKLEVELPARENTS._serialized_start=1350
  _BLOCKLEVELPARENTS._serialized_end=1408
  _HASH._serialized_start=1410
  _HASH._serialized_end=1431
  _REQUESTBLOCKLOCATORMESSAGE._serialized_start=1433
  _REQUESTBLOCKLOCATORMESSAGE._serialized_end=1511
  _BLOCKLOCATORMESSAGE._serialized_start=1513
  _BLOCKLOCATORMESSAGE._serialized_end=1567
  _REQUESTHEADERSMESSAGE._serialized_start=1569
  _REQUESTHEADERSMESSAGE._serialized_end=1661
  _REQUESTNEXTHEADERSMESSAGE._serialized_start=1663
  _REQUESTNEXTHEADERSMESSAGE._serialized_end=1690
  _DONEHEADERSMESSAGE._serialized_start=1692
  _DONEHEADERSMESSAGE._serialized_end=1712
  _REQUESTRELAYBLOCKSMESSAGE._serialized_start=1714
  _REQUESTRELAYBLOCKSMESSAGE._serialized_end=1774
  _REQUESTTRANSACTIONSMESSAGE._serialized_start=1776
  _REQUESTTRANSACTIONSMESSAGE._serialized_end=1843
  _TRANSACTIONNOTFOUNDMESSAGE._serialized_start=1845
  _TRANSACTIONNOTFOUNDMESSAGE._serialized_end=1911
  _INVRELAYBLOCKMESSAGE._serialized_start=1913
  _INVRELAYBLOCKMESSAGE._serialized_end=1966
  _INVTRANSACTIONSMESSAGE._serialized_start=1968
  _INVTRANSACTIONSMESSAGE._serialized_end=2031
  _PINGMESSAGE._serialized_start=2033
  _PINGMESSAGE._serialized_end=2061
  _PONGMESSAGE._serialized_start=2063
  _PONGMESSAGE._serialized_end=2091
  _VERACKMESSAGE._serialized_start=2093
  _VERACKMESSAGE._serialized_end=2108
  _VERSIONMESSAGE._serialized_start=2111
  _VERSIONMESSAGE._serialized_end=2348
  _REJECTMESSAGE._serialized_start=2350
  _REJECTMESSAGE._serialized_end=2381
  _REQUESTPRUNINGPOINTUTXOSETMESSAGE._serialized_start=2383
  _REQUESTPRUNINGPOINTUTXOSETMESSAGE._serialized_end=2461
  _PRUNINGPOINTUTXOSETCHUNKMESSAGE._serialized_start=2463
  _PRUNINGPOINTUTXOSETCHUNKMESSAGE._serialized_end=2568
  _OUTPOINTANDUTXOENTRYPAIR._serialized_start=2570
  _OUTPOINTANDUTXOENTRYPAIR._serialized_end=2676
  _UTXOENTRY._serialized_start=2678
  _UTXOENTRY._serialized_end=2801
  _REQUESTNEXTPRUNINGPOINTUTXOSETCHUNKMESSAGE._serialized_start=2803
  _REQUESTNEXTPRUNINGPOINTUTXOSETCHUNKMESSAGE._serialized_end=2847
  _DONEPRUNINGPOINTUTXOSETCHUNKSMESSAGE._serialized_start=2849
  _DONEPRUNINGPOINTUTXOSETCHUNKSMESSAGE._serialized_end=2887
  _REQUESTIBDBLOCKSMESSAGE._serialized_start=2889
  _REQUESTIBDBLOCKSMESSAGE._serialized_end=2947
  _UNEXPECTEDPRUNINGPOINTMESSAGE._serialized_start=2949
  _UNEXPECTEDPRUNINGPOINTMESSAGE._serialized_end=2980
  _IBDBLOCKLOCATORMESSAGE._serialized_start=2982
  _IBDBLOCKLOCATORMESSAGE._serialized_end=3088
  _REQUESTIBDCHAINBLOCKLOCATORMESSAGE._serialized_start=3090
  _REQUESTIBDCHAINBLOCKLOCATORMESSAGE._serialized_end=3195
  _IBDCHAINBLOCKLOCATORMESSAGE._serialized_start=3197
  _IBDCHAINBLOCKLOCATORMESSAGE._serialized_end=3271
  _REQUESTANTICONEMESSAGE._serialized_start=3273
  _REQUESTANTICONEMESSAGE._serialized_end=3371
  _IBDBLOCKLOCATORHIGHESTHASHMESSAGE._serialized_start=3373
  _IBDBLOCKLOCATORHIGHESTHASHMESSAGE._serialized_end=3446
  _IBDBLOCKLOCATORHIGHESTHASHNOTFOUNDMESSAGE._serialized_start=3448
  _IBDBLOCKLOCATORHIGHESTHASHNOTFOUNDMESSAGE._serialized_end=3491
  _BLOCKHEADERSMESSAGE._serialized_start=3493
  _BLOCKHEADERSMESSAGE._serialized_end=3560
  _REQUESTPRUNINGPOINTANDITSANTICONEMESSAGE._serialized_start=3562
  _REQUESTPRUNINGPOINTANDITSANTICONEMESSAGE._serialized_end=3604
  _REQUESTNEXTPRUNINGPOINTANDITSANTICONEBLOCKSMESSAGE._serialized_start=3606
  _REQUESTNEXTPRUNINGPOINTANDITSANTICONEBLOCKSMESSAGE._serialized_end=3658
  _BLOCKWITHTRUSTEDDATAMESSAGE._serialized_start=3661
  _BLOCKWITHTRUSTEDDATAMESSAGE._serialized_end=3848
  _DAABLOCK._serialized_start=3850
  _DAABLOCK._serialized_end=3947
  _DAABLOCKV4._serialized_start=3949
  _DAABLOCKV4._serialized_end=4048
  _BLOCKGHOSTDAGDATAHASHPAIR._serialized_start=4050
  _BLOCKGHOSTDAGDATAHASHPAIR._serialized_end=4155
  _GHOSTDAGDATA._serialized_start=4158
  _GHOSTDAGDATA._serialized_end=4388
  _BLUESANTICONESIZES._serialized_start=4390
  _BLUESANTICONESIZES._serialized_end=4467
  _DONEBLOCKSWITHTRUSTEDDATAMESSAGE._serialized_start=4469
  _DONEBLOCKSWITHTRUSTEDDATAMESSAGE._serialized_end=4503
  _PRUNINGPOINTSMESSAGE._serialized_start=4505
  _PRUNINGPOINTSMESSAGE._serialized_end=4568
  _REQUESTPRUNINGPOINTPROOFMESSAGE._serialized_start=4570
  _REQUESTPRUNINGPOINTPROOFMESSAGE._serialized_end=4603
  _PRUNINGPOINTPROOFMESSAGE._serialized_start=4605
  _PRUNINGPOINTPROOFMESSAGE._serialized_end=4689
  _PRUNINGPOINTPROOFHEADERARRAY._serialized_start=4691
  _PRUNINGPOINTPROOFHEADERARRAY._serialized_end=4762
  _READYMESSAGE._serialized_start=4764
  _READYMESSAGE._serialized_end=4778
  _BLOCKWITHTRUSTEDDATAV4MESSAGE._serialized_start=4780
  _BLOCKWITHTRUSTEDDATAV4MESSAGE._serialized_end=4906
  _TRUSTEDDATAMESSAGE._serialized_start=4908
  _TRUSTEDDATAMESSAGE._serialized_end=5030
# @@protoc_insertion_point(module_scope)




ABORT = '[aborted]'
SUCCESS = '[successs]'

class network:
    
    # messages pertaining to Scanning for a valid node
    SCANNING = f'''searching for nodes'''
    SCANNING_SEARCHING_FROM = lambda dns_server : f'''[{dns_server}]: finding nodes in dns seed server'''
    SCANNING_RETRIVED_NODES_FROM =  lambda dns_server, nodes : f'''[{dns_server}]: found the following nodes: {nodes}''' 
    SCANNING_RETRIVED_NODE_FROM = NotImplemented
    
    # messages pertaining to checking the status of the node
    CHECK_NODE = lambda node : f'''[{node}]: checking node...'''
    CHECK_APPROVED = '''all checks passed'''
    CHECK_DENIED = NotImplemented
    
    ## messages pertaining to checking the port  
    CHECK_PORT_DENIED = lambda node : f'''[{node}]: port is not OPEN {ABORT}'''
    CHECK_PORT_APPROVED = lambda node : f'''[{node}]: port is OPEN {SUCCESS}'''
    
    ## messages pertaining to checking the latency

    CHECK_LATENCY_DENIED = lambda node, latency, max_latency: f'''[{node}]: latency of {latency} is more then max latency of {max_latency}'''
    CHECK_LATENCY_APPROVED = lambda node, latency, max_latency :f'''[{node}]: latency of {latency} is less then max latency of {max_latency}'''
        
    LATENCY_QUERY = lambda node: f'''[{node}]: querying latency...'''
    CHECK_LATENCY_STAUTS_NONE = lambda node: f'''[{node}]: no connection estblished to check latency'''
    CHECK_LATENCY_STATUS_DELAY = lambda node, latency: f'''[{node}]: latency measured at {int(round(latency*1000, 0))} ms'''
    
    PORT_QUERY =  lambda node: f'''[{node}]: querying if port is open...'''
    CHECK_PORT_STAUTS_OPEN = lambda node, port : f'''[{node}]: port {port} is OPEN {SUCCESS}'''
    CHECK_PORT_STAUTS_CLOSED = lambda node, port : f'''[{node}]: port {port} is CLOSED {ABORT}'''
    
    
class client:
    
    #messages pertaining to client
    CLI_INTIALIZED = f'''starting a new client'''
    
    #messages pertaining to connection status
    CONN_ESTABLISHING = lambda node : f'''[{node}]: Connecting to node...'''
    CONN_ESTABLISHED = lambda node : f'''[{node}]: Connection established'''
    CONN_DISCONNECTING = NotImplemented
    CONN_DISCONNECTED = NotImplemented
    
    #Messages pertaining to sending / Reciving messages
    MSG_SENDING = lambda command, node : f'''[{node}]:[{command}]: Sending request..'''
    MSG_SENT = NotImplemented
    MSG_RECIVING = NotImplemented
    MSG_RECIVED = lambda response, command, node : f'''[{node}]:[{command}]: retrived response {response} {SUCCESS}'''



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: messages.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import service as _service
from google.protobuf import service_reflection
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import p2p_pb2 as p2p__pb2
from . import rpc_pb2 as rpc__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0emessages.proto\x12\tprotowire\x1a\tp2p.proto\x1a\trpc.proto\"\xd1R\n\rKaspadMessage\x12\x30\n\taddresses\x18\x01 \x01(\x0b\x32\x1b.protowire.AddressesMessageH\x00\x12(\n\x05\x62lock\x18\x02 \x01(\x0b\x32\x17.protowire.BlockMessageH\x00\x12\x34\n\x0btransaction\x18\x03 \x01(\x0b\x32\x1d.protowire.TransactionMessageH\x00\x12\x36\n\x0c\x62lockLocator\x18\x05 \x01(\x0b\x32\x1e.protowire.BlockLocatorMessageH\x00\x12>\n\x10requestAddresses\x18\x06 \x01(\x0b\x32\".protowire.RequestAddressesMessageH\x00\x12\x42\n\x12requestRelayBlocks\x18\n \x01(\x0b\x32$.protowire.RequestRelayBlocksMessageH\x00\x12\x44\n\x13requestTransactions\x18\x0c \x01(\x0b\x32%.protowire.RequestTransactionsMessageH\x00\x12+\n\x08ibdBlock\x18\r \x01(\x0b\x32\x17.protowire.BlockMessageH\x00\x12\x38\n\rinvRelayBlock\x18\x0e \x01(\x0b\x32\x1f.protowire.InvRelayBlockMessageH\x00\x12<\n\x0finvTransactions\x18\x0f \x01(\x0b\x32!.protowire.InvTransactionsMessageH\x00\x12&\n\x04ping\x18\x10 \x01(\x0b\x32\x16.protowire.PingMessageH\x00\x12&\n\x04pong\x18\x11 \x01(\x0b\x32\x16.protowire.PongMessageH\x00\x12*\n\x06verack\x18\x13 \x01(\x0b\x32\x18.protowire.VerackMessageH\x00\x12,\n\x07version\x18\x14 \x01(\x0b\x32\x19.protowire.VersionMessageH\x00\x12\x44\n\x13transactionNotFound\x18\x15 \x01(\x0b\x32%.protowire.TransactionNotFoundMessageH\x00\x12*\n\x06reject\x18\x16 \x01(\x0b\x32\x18.protowire.RejectMessageH\x00\x12N\n\x18pruningPointUtxoSetChunk\x18\x19 \x01(\x0b\x32*.protowire.PruningPointUtxoSetChunkMessageH\x00\x12>\n\x10requestIBDBlocks\x18\x1a \x01(\x0b\x32\".protowire.RequestIBDBlocksMessageH\x00\x12J\n\x16unexpectedPruningPoint\x18\x1b \x01(\x0b\x32(.protowire.UnexpectedPruningPointMessageH\x00\x12<\n\x0fibdBlockLocator\x18\x1e \x01(\x0b\x32!.protowire.IbdBlockLocatorMessageH\x00\x12R\n\x1aibdBlockLocatorHighestHash\x18\x1f \x01(\x0b\x32,.protowire.IbdBlockLocatorHighestHashMessageH\x00\x12\x64\n#requestNextPruningPointUtxoSetChunk\x18! \x01(\x0b\x32\x35.protowire.RequestNextPruningPointUtxoSetChunkMessageH\x00\x12X\n\x1d\x64onePruningPointUtxoSetChunks\x18\" \x01(\x0b\x32/.protowire.DonePruningPointUtxoSetChunksMessageH\x00\x12\x62\n\"ibdBlockLocatorHighestHashNotFound\x18# \x01(\x0b\x32\x34.protowire.IbdBlockLocatorHighestHashNotFoundMessageH\x00\x12\x46\n\x14\x62lockWithTrustedData\x18$ \x01(\x0b\x32&.protowire.BlockWithTrustedDataMessageH\x00\x12P\n\x19\x64oneBlocksWithTrustedData\x18% \x01(\x0b\x32+.protowire.DoneBlocksWithTrustedDataMessageH\x00\x12`\n!requestPruningPointAndItsAnticone\x18( \x01(\x0b\x32\x33.protowire.RequestPruningPointAndItsAnticoneMessageH\x00\x12\x36\n\x0c\x62lockHeaders\x18) \x01(\x0b\x32\x1e.protowire.BlockHeadersMessageH\x00\x12\x42\n\x12requestNextHeaders\x18* \x01(\x0b\x32$.protowire.RequestNextHeadersMessageH\x00\x12\x34\n\x0b\x44oneHeaders\x18+ \x01(\x0b\x32\x1d.protowire.DoneHeadersMessageH\x00\x12R\n\x1arequestPruningPointUTXOSet\x18, \x01(\x0b\x32,.protowire.RequestPruningPointUTXOSetMessageH\x00\x12:\n\x0erequestHeaders\x18- \x01(\x0b\x32 .protowire.RequestHeadersMessageH\x00\x12\x44\n\x13requestBlockLocator\x18. \x01(\x0b\x32%.protowire.RequestBlockLocatorMessageH\x00\x12\x38\n\rpruningPoints\x18/ \x01(\x0b\x32\x1f.protowire.PruningPointsMessageH\x00\x12N\n\x18requestPruningPointProof\x18\x30 \x01(\x0b\x32*.protowire.RequestPruningPointProofMessageH\x00\x12@\n\x11pruningPointProof\x18\x31 \x01(\x0b\x32#.protowire.PruningPointProofMessageH\x00\x12(\n\x05ready\x18\x32 \x01(\x0b\x32\x17.protowire.ReadyMessageH\x00\x12J\n\x16\x62lockWithTrustedDataV4\x18\x33 \x01(\x0b\x32(.protowire.BlockWithTrustedDataV4MessageH\x00\x12\x34\n\x0btrustedData\x18\x34 \x01(\x0b\x32\x1d.protowire.TrustedDataMessageH\x00\x12T\n\x1brequestIBDChainBlockLocator\x18\x35 \x01(\x0b\x32-.protowire.RequestIBDChainBlockLocatorMessageH\x00\x12\x46\n\x14ibdChainBlockLocator\x18\x36 \x01(\x0b\x32&.protowire.IbdChainBlockLocatorMessageH\x00\x12<\n\x0frequestAnticone\x18\x37 \x01(\x0b\x32!.protowire.RequestAnticoneMessageH\x00\x12t\n+requestNextPruningPointAndItsAnticoneBlocks\x18\x38 \x01(\x0b\x32=.protowire.RequestNextPruningPointAndItsAnticoneBlocksMessageH\x00\x12O\n\x18getCurrentNetworkRequest\x18\xe9\x07 \x01(\x0b\x32*.protowire.GetCurrentNetworkRequestMessageH\x00\x12Q\n\x19getCurrentNetworkResponse\x18\xea\x07 \x01(\x0b\x32+.protowire.GetCurrentNetworkResponseMessageH\x00\x12\x43\n\x12submitBlockRequest\x18\xeb\x07 \x01(\x0b\x32$.protowire.SubmitBlockRequestMessageH\x00\x12\x45\n\x13submitBlockResponse\x18\xec\x07 \x01(\x0b\x32%.protowire.SubmitBlockResponseMessageH\x00\x12M\n\x17getBlockTemplateRequest\x18\xed\x07 \x01(\x0b\x32).protowire.GetBlockTemplateRequestMessageH\x00\x12O\n\x18getBlockTemplateResponse\x18\xee\x07 \x01(\x0b\x32*.protowire.GetBlockTemplateResponseMessageH\x00\x12M\n\x17notifyBlockAddedRequest\x18\xef\x07 \x01(\x0b\x32).protowire.NotifyBlockAddedRequestMessageH\x00\x12O\n\x18notifyBlockAddedResponse\x18\xf0\x07 \x01(\x0b\x32*.protowire.NotifyBlockAddedResponseMessageH\x00\x12K\n\x16\x62lockAddedNotification\x18\xf1\x07 \x01(\x0b\x32(.protowire.BlockAddedNotificationMessageH\x00\x12M\n\x17getPeerAddressesRequest\x18\xf2\x07 \x01(\x0b\x32).protowire.GetPeerAddressesRequestMessageH\x00\x12O\n\x18getPeerAddressesResponse\x18\xf3\x07 \x01(\x0b\x32*.protowire.GetPeerAddressesResponseMessageH\x00\x12Q\n\x19getSelectedTipHashRequest\x18\xf4\x07 \x01(\x0b\x32+.protowire.GetSelectedTipHashRequestMessageH\x00\x12S\n\x1agetSelectedTipHashResponse\x18\xf5\x07 \x01(\x0b\x32,.protowire.GetSelectedTipHashResponseMessageH\x00\x12K\n\x16getMempoolEntryRequest\x18\xf6\x07 \x01(\x0b\x32(.protowire.GetMempoolEntryRequestMessageH\x00\x12M\n\x17getMempoolEntryResponse\x18\xf7\x07 \x01(\x0b\x32).protowire.GetMempoolEntryResponseMessageH\x00\x12U\n\x1bgetConnectedPeerInfoRequest\x18\xf8\x07 \x01(\x0b\x32-.protowire.GetConnectedPeerInfoRequestMessageH\x00\x12W\n\x1cgetConnectedPeerInfoResponse\x18\xf9\x07 \x01(\x0b\x32..protowire.GetConnectedPeerInfoResponseMessageH\x00\x12;\n\x0e\x61\x64\x64PeerRequest\x18\xfa\x07 \x01(\x0b\x32 .protowire.AddPeerRequestMessageH\x00\x12=\n\x0f\x61\x64\x64PeerResponse\x18\xfb\x07 \x01(\x0b\x32!.protowire.AddPeerResponseMessageH\x00\x12O\n\x18submitTransactionRequest\x18\xfc\x07 \x01(\x0b\x32*.protowire.SubmitTransactionRequestMessageH\x00\x12Q\n\x19submitTransactionResponse\x18\xfd\x07 \x01(\x0b\x32+.protowire.SubmitTransactionResponseMessageH\x00\x12{\n.notifyVirtualSelectedParentChainChangedRequest\x18\xfe\x07 \x01(\x0b\x32@.protowire.NotifyVirtualSelectedParentChainChangedRequestMessageH\x00\x12}\n/notifyVirtualSelectedParentChainChangedResponse\x18\xff\x07 \x01(\x0b\x32\x41.protowire.NotifyVirtualSelectedParentChainChangedResponseMessageH\x00\x12y\n-virtualSelectedParentChainChangedNotification\x18\x80\x08 \x01(\x0b\x32?.protowire.VirtualSelectedParentChainChangedNotificationMessageH\x00\x12=\n\x0fgetBlockRequest\x18\x81\x08 \x01(\x0b\x32!.protowire.GetBlockRequestMessageH\x00\x12?\n\x10getBlockResponse\x18\x82\x08 \x01(\x0b\x32\".protowire.GetBlockResponseMessageH\x00\x12G\n\x14getSubnetworkRequest\x18\x83\x08 \x01(\x0b\x32&.protowire.GetSubnetworkRequestMessageH\x00\x12I\n\x15getSubnetworkResponse\x18\x84\x08 \x01(\x0b\x32\'.protowire.GetSubnetworkResponseMessageH\x00\x12y\n-getVirtualSelectedParentChainFromBlockRequest\x18\x85\x08 \x01(\x0b\x32?.protowire.GetVirtualSelectedParentChainFromBlockRequestMessageH\x00\x12{\n.getVirtualSelectedParentChainFromBlockResponse\x18\x86\x08 \x01(\x0b\x32@.protowire.GetVirtualSelectedParentChainFromBlockResponseMessageH\x00\x12?\n\x10getBlocksRequest\x18\x87\x08 \x01(\x0b\x32\".protowire.GetBlocksRequestMessageH\x00\x12\x41\n\x11getBlocksResponse\x18\x88\x08 \x01(\x0b\x32#.protowire.GetBlocksResponseMessageH\x00\x12G\n\x14getBlockCountRequest\x18\x89\x08 \x01(\x0b\x32&.protowire.GetBlockCountRequestMessageH\x00\x12I\n\x15getBlockCountResponse\x18\x8a\x08 \x01(\x0b\x32\'.protowire.GetBlockCountResponseMessageH\x00\x12K\n\x16getBlockDagInfoRequest\x18\x8b\x08 \x01(\x0b\x32(.protowire.GetBlockDagInfoRequestMessageH\x00\x12M\n\x17getBlockDagInfoResponse\x18\x8c\x08 \x01(\x0b\x32).protowire.GetBlockDagInfoResponseMessageH\x00\x12[\n\x1eresolveFinalityConflictRequest\x18\x8d\x08 \x01(\x0b\x32\x30.protowire.ResolveFinalityConflictRequestMessageH\x00\x12]\n\x1fresolveFinalityConflictResponse\x18\x8e\x08 \x01(\x0b\x32\x31.protowire.ResolveFinalityConflictResponseMessageH\x00\x12[\n\x1enotifyFinalityConflictsRequest\x18\x8f\x08 \x01(\x0b\x32\x30.protowire.NotifyFinalityConflictsRequestMessageH\x00\x12]\n\x1fnotifyFinalityConflictsResponse\x18\x90\x08 \x01(\x0b\x32\x31.protowire.NotifyFinalityConflictsResponseMessageH\x00\x12W\n\x1c\x66inalityConflictNotification\x18\x91\x08 \x01(\x0b\x32..protowire.FinalityConflictNotificationMessageH\x00\x12g\n$finalityConflictResolvedNotification\x18\x92\x08 \x01(\x0b\x32\x36.protowire.FinalityConflictResolvedNotificationMessageH\x00\x12O\n\x18getMempoolEntriesRequest\x18\x93\x08 \x01(\x0b\x32*.protowire.GetMempoolEntriesRequestMessageH\x00\x12Q\n\x19getMempoolEntriesResponse\x18\x94\x08 \x01(\x0b\x32+.protowire.GetMempoolEntriesResponseMessageH\x00\x12=\n\x0fshutDownRequest\x18\x95\x08 \x01(\x0b\x32!.protowire.ShutDownRequestMessageH\x00\x12?\n\x10shutDownResponse\x18\x96\x08 \x01(\x0b\x32\".protowire.ShutDownResponseMessageH\x00\x12\x41\n\x11getHeadersRequest\x18\x97\x08 \x01(\x0b\x32#.protowire.GetHeadersRequestMessageH\x00\x12\x43\n\x12getHeadersResponse\x18\x98\x08 \x01(\x0b\x32$.protowire.GetHeadersResponseMessageH\x00\x12Q\n\x19notifyUtxosChangedRequest\x18\x99\x08 \x01(\x0b\x32+.protowire.NotifyUtxosChangedRequestMessageH\x00\x12S\n\x1anotifyUtxosChangedResponse\x18\x9a\x08 \x01(\x0b\x32,.protowire.NotifyUtxosChangedResponseMessageH\x00\x12O\n\x18utxosChangedNotification\x18\x9b\x08 \x01(\x0b\x32*.protowire.UtxosChangedNotificationMessageH\x00\x12S\n\x1agetUtxosByAddressesRequest\x18\x9c\x08 \x01(\x0b\x32,.protowire.GetUtxosByAddressesRequestMessageH\x00\x12U\n\x1bgetUtxosByAddressesResponse\x18\x9d\x08 \x01(\x0b\x32-.protowire.GetUtxosByAddressesResponseMessageH\x00\x12o\n(getVirtualSelectedParentBlueScoreRequest\x18\x9e\x08 \x01(\x0b\x32:.protowire.GetVirtualSelectedParentBlueScoreRequestMessageH\x00\x12q\n)getVirtualSelectedParentBlueScoreResponse\x18\x9f\x08 \x01(\x0b\x32;.protowire.GetVirtualSelectedParentBlueScoreResponseMessageH\x00\x12\x83\x01\n2notifyVirtualSelectedParentBlueScoreChangedRequest\x18\xa0\x08 \x01(\x0b\x32\x44.protowire.NotifyVirtualSelectedParentBlueScoreChangedRequestMessageH\x00\x12\x85\x01\n3notifyVirtualSelectedParentBlueScoreChangedResponse\x18\xa1\x08 \x01(\x0b\x32\x45.protowire.NotifyVirtualSelectedParentBlueScoreChangedResponseMessageH\x00\x12\x81\x01\n1virtualSelectedParentBlueScoreChangedNotification\x18\xa2\x08 \x01(\x0b\x32\x43.protowire.VirtualSelectedParentBlueScoreChangedNotificationMessageH\x00\x12\x33\n\nbanRequest\x18\xa3\x08 \x01(\x0b\x32\x1c.protowire.BanRequestMessageH\x00\x12\x35\n\x0b\x62\x61nResponse\x18\xa4\x08 \x01(\x0b\x32\x1d.protowire.BanResponseMessageH\x00\x12\x37\n\x0cunbanRequest\x18\xa5\x08 \x01(\x0b\x32\x1e.protowire.UnbanRequestMessageH\x00\x12\x39\n\runbanResponse\x18\xa6\x08 \x01(\x0b\x32\x1f.protowire.UnbanResponseMessageH\x00\x12;\n\x0egetInfoRequest\x18\xa7\x08 \x01(\x0b\x32 .protowire.GetInfoRequestMessageH\x00\x12=\n\x0fgetInfoResponse\x18\xa8\x08 \x01(\x0b\x32!.protowire.GetInfoResponseMessageH\x00\x12_\n stopNotifyingUtxosChangedRequest\x18\xa9\x08 \x01(\x0b\x32\x32.protowire.StopNotifyingUtxosChangedRequestMessageH\x00\x12\x61\n!stopNotifyingUtxosChangedResponse\x18\xaa\x08 \x01(\x0b\x32\x33.protowire.StopNotifyingUtxosChangedResponseMessageH\x00\x12o\n(notifyPruningPointUTXOSetOverrideRequest\x18\xab\x08 \x01(\x0b\x32:.protowire.NotifyPruningPointUTXOSetOverrideRequestMessageH\x00\x12q\n)notifyPruningPointUTXOSetOverrideResponse\x18\xac\x08 \x01(\x0b\x32;.protowire.NotifyPruningPointUTXOSetOverrideResponseMessageH\x00\x12m\n\'pruningPointUTXOSetOverrideNotification\x18\xad\x08 \x01(\x0b\x32\x39.protowire.PruningPointUTXOSetOverrideNotificationMessageH\x00\x12}\n/stopNotifyingPruningPointUTXOSetOverrideRequest\x18\xae\x08 \x01(\x0b\x32\x41.protowire.StopNotifyingPruningPointUTXOSetOverrideRequestMessageH\x00\x12\x7f\n0stopNotifyingPruningPointUTXOSetOverrideResponse\x18\xaf\x08 \x01(\x0b\x32\x42.protowire.StopNotifyingPruningPointUTXOSetOverrideResponseMessageH\x00\x12i\n%estimateNetworkHashesPerSecondRequest\x18\xb0\x08 \x01(\x0b\x32\x37.protowire.EstimateNetworkHashesPerSecondRequestMessageH\x00\x12k\n&estimateNetworkHashesPerSecondResponse\x18\xb1\x08 \x01(\x0b\x32\x38.protowire.EstimateNetworkHashesPerSecondResponseMessageH\x00\x12\x65\n#notifyVirtualDaaScoreChangedRequest\x18\xb2\x08 \x01(\x0b\x32\x35.protowire.NotifyVirtualDaaScoreChangedRequestMessageH\x00\x12g\n$notifyVirtualDaaScoreChangedResponse\x18\xb3\x08 \x01(\x0b\x32\x36.protowire.NotifyVirtualDaaScoreChangedResponseMessageH\x00\x12\x63\n\"virtualDaaScoreChangedNotification\x18\xb4\x08 \x01(\x0b\x32\x34.protowire.VirtualDaaScoreChangedNotificationMessageH\x00\x12S\n\x1agetBalanceByAddressRequest\x18\xb5\x08 \x01(\x0b\x32,.protowire.GetBalanceByAddressRequestMessageH\x00\x12U\n\x1bgetBalanceByAddressResponse\x18\xb6\x08 \x01(\x0b\x32-.protowire.GetBalanceByAddressResponseMessageH\x00\x12Y\n\x1dgetBalancesByAddressesRequest\x18\xb7\x08 \x01(\x0b\x32/.protowire.GetBalancesByAddressesRequestMessageH\x00\x12[\n\x1egetBalancesByAddressesResponse\x18\xb8\x08 \x01(\x0b\x32\x30.protowire.GetBalancesByAddressesResponseMessageH\x00\x12Y\n\x1dnotifyNewBlockTemplateRequest\x18\xb9\x08 \x01(\x0b\x32/.protowire.NotifyNewBlockTemplateRequestMessageH\x00\x12[\n\x1enotifyNewBlockTemplateResponse\x18\xba\x08 \x01(\x0b\x32\x30.protowire.NotifyNewBlockTemplateResponseMessageH\x00\x12W\n\x1cnewBlockTemplateNotification\x18\xbb\x08 \x01(\x0b\x32..protowire.NewBlockTemplateNotificationMessageH\x00\x12\x65\n#getMempoolEntriesByAddressesRequest\x18\xbc\x08 \x01(\x0b\x32\x35.protowire.GetMempoolEntriesByAddressesRequestMessageH\x00\x12g\n$getMempoolEntriesByAddressesResponse\x18\xbd\x08 \x01(\x0b\x32\x36.protowire.GetMempoolEntriesByAddressesResponseMessageH\x00\x12G\n\x14getCoinSupplyRequest\x18\xbe\x08 \x01(\x0b\x32&.protowire.GetCoinSupplyRequestMessageH\x00\x12I\n\x15getCoinSupplyResponse\x18\xbf\x08 \x01(\x0b\x32\'.protowire.GetCoinSupplyResponseMessageH\x00\x42\t\n\x07payload2P\n\x03P2P\x12I\n\rMessageStream\x12\x18.protowire.KaspadMessage\x1a\x18.protowire.KaspadMessage\"\x00(\x01\x30\x01\x32P\n\x03RPC\x12I\n\rMessageStream\x12\x18.protowire.KaspadMessage\x1a\x18.protowire.KaspadMessage\"\x00(\x01\x30\x01\x42)Z$github.com/kaspanet/kaspad/protowire\x90\x01\x01\x62\x06proto3')



_KASPADMESSAGE = DESCRIPTOR.message_types_by_name['KaspadMessage']
KaspadMessage = _reflection.GeneratedProtocolMessageType('KaspadMessage', (_message.Message,), {
  'DESCRIPTOR' : _KASPADMESSAGE,
  '__module__' : 'messages_pb2'
  # @@protoc_insertion_point(class_scope:protowire.KaspadMessage)
  })
_sym_db.RegisterMessage(KaspadMessage)

_P2P = DESCRIPTOR.services_by_name['P2P']
_RPC = DESCRIPTOR.services_by_name['RPC']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z$github.com/kaspanet/kaspad/protowire\220\001\001'
  _KASPADMESSAGE._serialized_start=52
  _KASPADMESSAGE._serialized_end=10629
  _P2P._serialized_start=10631
  _P2P._serialized_end=10711
  _RPC._serialized_start=10713
  _RPC._serialized_end=10793
P2P = service_reflection.GeneratedServiceType('P2P', (_service.Service,), dict(
  DESCRIPTOR = _P2P,
  __module__ = 'messages_pb2'
  ))

P2P_Stub = service_reflection.GeneratedServiceStubType('P2P_Stub', (P2P,), dict(
  DESCRIPTOR = _P2P,
  __module__ = 'messages_pb2'
  ))


RPC = service_reflection.GeneratedServiceType('RPC', (_service.Service,), dict(
  DESCRIPTOR = _RPC,
  __module__ = 'messages_pb2'
  ))

RPC_Stub = service_reflection.GeneratedServiceStubType('RPC_Stub', (RPC,), dict(
  DESCRIPTOR = _RPC,
  __module__ = 'messages_pb2'
  ))


# @@protoc_insertion_point(module_scope)



from __future__ import annotations
from typing import Union


class version(object):
        
    @classmethod
    def parse_from_string(cls, string : str) -> version:
        split_string = string.rsplit('.')
        major, minor, bug_fix = 0, 0, 0 
        major, minor, bug_fix = tuple(split_string[-3:])
        major = int(''.join(filter(str.isdigit, (x for x in major))))
        minor = int(''.join(filter(str.isdigit, (x for x in minor))))
        bug_fix = int(''.join(filter(str.isdigit, (x for x in bug_fix))))
        return version(major, minor, bug_fix)
    
    
    def __init__(self, major: int , minor: int, bug_fix: int) -> None:
        self.major =  major
        self.minor = minor
        self.bug_fix = bug_fix
        assert all(isinstance(v, int) for v in [self.major, self.minor, self.bug_fix]) #only allow numerival and 'x' or 'XX notation
    
    
    def __eq__(self, comp: version) -> bool:
        if (self.major == comp.major) and (
            self.minor == comp.minor) and (
            self.bug_fix == comp.bug_fix):
            return True
        else:
            return False
    
    def __lt__(self, comp: version) -> bool:
        if self.major < comp.major:
            return True
        elif self.minor < comp.minor:
            return True
        elif self.bug_fix < comp.bug_fix:
            return True
        else:
            return False
    
    def __gt__(self, comp : version) -> bool:
        if self.major > comp.major:
            return True
        elif self.minor > comp.minor:
            return True
        elif self.bug_fix > comp.bug_fix:
            return True
        else:
            return False
    
    def __le__(self, comp: version) -> bool:
        return self.__eq__(comp) | self.__lt__(comp)
    
    def __ge__(self, comp: version) -> bool:
        return self.__eq__(comp) | self.__gt__(comp)
    
    def __str__(self):
        return f'v{self.major}.{self.minor}.{self.bug_fix}'


#from kaspy import __version__ as VERSION, __name__ as NAME
import setuptools
from kaspy import __name__, __version__
 
with open("README.md", "r") as fh:
    long_description = fh.read()

with open("requirements.txt","r") as f:
    dependencies = f.read().splitlines()

setuptools.setup(
    name=__name__,
    version= __version__,
    author="D-Stacks",
    description="Python implementation of a kaspa grpc client",
    long_description = long_description,
    long_description_content_type="text/markdown",
    packages=setuptools.find_packages(),
    license= 'GPL-3.0 License',
    install_requires= dependencies,
    url= 'https://github.com/kaspagang/kaspy',
    classifiers=[
        "Programming Language :: Python :: 3",
    ],
    python_requires='>=3.8', #only version tested
)



from kaspy.defines import P2P_SERVICE, RPC_SERVICE

class RPCResponseException(Exception):
    def __init__(self, node, code, details):
        '''Exception that is raised when server cannot process a request'''
        super().__init__(f'{code}: did not get valid response from host {node}; {details}')
        
class CLientClosed(Exception):
    def __init__(self, node, command):
        '''Exception that is raised when client is closed and tries to send data'''
        super().__init__(f'could not send {command} to host {node} because the client is CLOSED')
    
class ClientDisconnected(Exception):
    def __init__(self, node, command):
        '''Exception that is raised when client is disconnected and tries to send data'''
        super().__init__(f'could not send {command} to host {node} because the client is DISCONNECTED')

class WrongService(Exception):
    def __init__(self, node, server_service, command):
        '''Exception that is raised when client is trying to send P2P commands to RPC, and vice versa'''
        super().__init__(
            f'''
            could not send {command} to {server_service} host {node}; command is a 
            {RPC_SERVICE if server_service == P2P_SERVICE else P2P_SERVICE} command
            ''')
class RPCServiceUnavailable(Exception):
    def __init__(self, node, code, details):
        super().__init__(f'Service on {node} is currently {code}.. Reason: {details}')
              
class InvalidCommand(Exception):
    def __init__(self, node, command):
        '''Exception that is raised when command is not registered anywhere in the proto files'''
        super().__init__(f'could not send command {command} to {node}; {command} is not a valid command')

class CommandIsNotSubcribable(Exception):
     def __init__(self, node, command):
        '''Exception that is raised when command is not registered anywhere in the proto files'''
        super().__init__(f'cannot subscribe to {node} with {command}; {command} is not subscribable')

class SubscriptionCannotBeUnsubscribed(Exception):
     def __init__(self, node, command):
        '''Exception that is raised when command is not registered anywhere in the proto files'''
        super().__init__(f'cannot unsubscribe to {command} in {node}')
    
